@@ -1,4 +1,4 @@
-# Copyright 2010, 2011  Lars Wirzenius
+# Copyright 2010, 2011, 2012  Lars Wirzenius
 # 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,20 +14,28 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-__version__ = '0.27'
+__version__ = '1.20120527'
+
+
+class Error(Exception):
+
+    def __str__(self):
+        return self.msg
 
 
 from nodes import FrozenNode, Node, LeafNode, IndexNode
 from codec import NodeCodec, CodecError
 from tree import BTree, KeySizeMismatch, ValueTooLarge
-from forest import Forest, open_forest, BadKeySize, BadNodeSize
+from forest import (Forest, open_forest, BadKeySize, BadNodeSize, 
+                    MetadataMissingKey)
 from nodestore import (NodeStore, NodeStoreTests, NodeMissing, NodeTooBig, 
                        NodeExists, NodeCannotBeModified)
 from refcountstore import RefcountStore
 from lru import LRUCache
 from uploadqueue import UploadQueue
 from idpath import IdPath
-from nodestore_disk import NodeStoreDisk, LocalFS
+from journal import Journal, ReadOnlyMode
+from nodestore_disk import NodeStoreDisk, LocalFS, FormatProblem
 from nodestore_memory import NodeStoreMemory
 
 __all__ = locals()
